@@ -26,6 +26,9 @@
 # HUBzero is a registered trademark of HUBzero Foundation, LLC.
 #
 
+import sys
+sys.path.insert(1,"/usr/lib/python2.6/dist-packages")
+
 import base64
 import cgi
 import ConfigParser
@@ -191,7 +194,7 @@ def db_connect():
 			db = MySQLdb.connect(host=mysql_host, user=mysql_user, passwd=mysql_password, db=mysql_db)
 			#log("db_connect finished on iteration %d" % x)
 			return db
-		except ex:
+		except Exception as ex:
 			log("Exception in db_connect: \n" + str(ex) + "\n" + traceback.format_exc())
 
 	time.sleep(1)
