@@ -26,6 +26,9 @@
 # HUBzero is a registered trademark of HUBzero Foundation, LLC.
 #
 
+import sys
+sys.path.insert(1,"/usr/lib/python2.6/dist-packages")
+
 import base64
 import cgi
 import ConfigParser
@@ -341,7 +344,7 @@ try:
 
 				db.close()
 			else:
-				username = '<anonymous>'
+				username = '<non-hub user>'
 
 			# update ticket status, then return string to insert comment documenting changes
 			changelog += setTicketToOpenStatus(ticketID, ticketStatus, ticketResolved, username)
